# napari-text-layer

Napari text layer for bio-image annotation.

![](GIFs/annot.gif)
![](GIFs/age.gif)

### Keybindings and mouse callbacks

- "&rarr;", "&larr;", "&uarr;", "&darr;" ... Move selected shapes by 1 pixel.
- "F2" ... Enter edit mode at the selected shape (or the last one if no shape is selected).
- "Enter" ... Finish edit mode or add a new shape at the same interval.
- "Ctrl" + "Shift" + "<" or ">" ... Change font size.
- double click ... Enter edit mode at the clicked shape.
